A collection of helpful functions, classes, and files.

## Namespaces

`libtalley`:
- Catch-all.

`libtalley.steeldesign`:
- Design of steel members by AISC 360-16 and AISC 341-16.

`libtalley.fema_p695`:
- Helper functions for FEMA P695 studies. Ported from Mark Denavit's MATLAB code.

`libtalley.latex_format`:
- Functions that format strings into LaTeX representations.

`libtalley.asce7_16`:
- Calculation of loads by ASCE 7-16. Contains the following modules:
    - `seismic`: seismic loads (Chapters 11, 12)
